/**
 * ========================================
 * <libname> : a free Java <foobar> library
 * ========================================
 *
 * Project Info:  http://www.jfree.org/liblayout/
 * Project Lead:  Thomas Morgner;
 *
 * (C) Copyright 2005, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * ---------
 * JakartaLogModule.java
 * ---------
 *
 * Original Author:  Thomas Morgner;
 * Contributors: -;
 *
 * $Id: JakartaLogModule.java,v 1.1 2006/03/23 19:39:57 taqua Exp $
 *
 * Changes
 * -------------------------
 * 23.03.2006 : Initial version
 */
package org.jfree.logger.jcl;

import org.jfree.base.BaseBoot;
import org.jfree.base.log.LogConfiguration;
import org.jfree.base.modules.AbstractModule;
import org.jfree.base.modules.ModuleInitializeException;
import org.jfree.base.modules.SubSystem;
import org.jfree.util.Configuration;
import org.jfree.util.Log;

/**
 * Creation-Date: 23.03.2006, 19:30:30
 *
 * @author Thomas Morgner
 */
public class JakartaLogModule extends AbstractModule
{
  /**
   * DefaultConstructor. Loads the module specification.
   * @throws ModuleInitializeException if an error occured.
   */
  public JakartaLogModule() throws ModuleInitializeException
  {
    loadModuleInfo();
  }

  /**
   * Initalizes the module. This method is empty.
   *
   * @throws ModuleInitializeException if an error occured.
   */
  public void initialize(final SubSystem subSystem) throws ModuleInitializeException
  {
    if (LogConfiguration.isDisableLogging())
    {
      return;
    }

    final Configuration config = BaseBoot.getConfiguration();
    if (JakartaLogTarget.class.getName().equals
            (config.getConfigProperty(LogConfiguration.LOGTARGET)))
    {
      JakartaLog.install();
      if ("true".equals(subSystem.getGlobalConfig().getConfigProperty
              ("org.jfree.base.LogAutoInit")))
      {
        Log.getInstance().init();
      }
      Log.info ("Jakarta log target started ... previous log messages could have been ignored.");
    }
  }
}
